@@ -1,7 +1,3 @@
-( cd opt/kde/lib/kde3 ; rm -rf libdialogpages.so )
-( cd opt/kde/lib/kde3 ; ln -sf libdialogpages.so.0.0.0 libdialogpages.so )
-( cd opt/kde/lib/kde3 ; rm -rf libdialogpages.so.0 )
-( cd opt/kde/lib/kde3 ; ln -sf libdialogpages.so.0.0.0 libdialogpages.so.0 )
 ( cd opt/kde/lib ; rm -rf libkbabelcommon.so )
 ( cd opt/kde/lib ; ln -sf libkbabelcommon.so.3.2.0 libkbabelcommon.so )
 ( cd opt/kde/lib ; rm -rf libkspy.so.1 )
@@ -12,6 +8,10 @@
 ( cd opt/kde/lib ; ln -sf libcvsservice.so.0.0.1 libcvsservice.so.0 )
 ( cd opt/kde/lib ; rm -rf libcvsservice.so )
 ( cd opt/kde/lib ; ln -sf libcvsservice.so.0.0.1 libcvsservice.so )
+( cd opt/kde/lib ; rm -rf libkunittestgui.so )
+( cd opt/kde/lib ; ln -sf libkunittestgui.so.0.0.0 libkunittestgui.so )
+( cd opt/kde/lib ; rm -rf libkunittestgui.so.0 )
+( cd opt/kde/lib ; ln -sf libkunittestgui.so.0.0.0 libkunittestgui.so.0 )
 ( cd opt/kde/lib ; rm -rf libkompareinterface.so )
 ( cd opt/kde/lib ; ln -sf libkompareinterface.so.0.0.0 libkompareinterface.so )
 ( cd opt/kde/lib ; rm -rf libkbabeldictplugin.so )
@@ -28,6 +28,8 @@
 ( cd opt/kde/share/doc/HTML/en/kompare ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcachegrind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kdesvn-build ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kdesvn-build ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kbabel ; rm -rf common )
